@@ -78,7 +78,7 @@
 #' 
 #' The second argument \code{which} indicates which sort of plot(s)
 #' should be shown. For \code{which="regression"}, a scatter plot of
-#' the quantil-transformed proportions of negative test results with
+#' the quantile-transformed proportions of negative test results with
 #' two regression lines is shown. Points belonging to the same study
 #' are marked with the same colour. For \code{which="cdf"}, the two
 #' cumulative distribution functions are shown, corresponding to the
@@ -211,11 +211,7 @@ plot.diagmeta <- function(x,
                           ...) {
   
   
-  meta:::chkclass(x, "diagmeta")
-  ##
-  setchar <- meta:::setchar
-  chklength <- meta:::chklength
-  chklogical <- meta:::chklogical
+  chkclass(x, "diagmeta")
   ##
   plot.types <- c("regression", "cdf", "survival", "youden",
                   "roc", "sroc", "density", "sensspec")
@@ -261,7 +257,7 @@ plot.diagmeta <- function(x,
   chklogical(rlines)
   chklogical(line.optcut)
   ##
-  meta:::chkchar(col.points)
+  chkchar(col.points)
   col.points <- setchar(col.points,
                         c("rainbow", "topo", "heat", "terrain",
                           "cm", "grayscale", colours()),
